# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .parameter import Parameter

__all__ = ["GraphSetParametersResponse"]

GraphSetParametersResponse: TypeAlias = List[Parameter]
